import type { MenuModule, AppRouteRecordRaw, AppRouteModule } from '@/router/types';

import { PAGE_NOT_FOUND_ROUTE, REDIRECT_ROUTE } from '@/router/routes/basic';
import { mainOutRoutes } from './mainOut';
import { PageEnum } from '@/enums/pageEnum';
import { t } from '@/hooks/web/useI18n';
import { filter } from '@/utils/helper/treeHelper';
import { getList } from '@/api/role';

// import.meta.glob() 直接引入所有的模块 Vite 独有的功能
const modules = import.meta.glob('./modules/**/*.ts', { eager: true });
const routeModuleList: AppRouteModule[] = [];
let roleList;
if (localStorage.getItem('urlRoles')) {
  const str: any = localStorage.getItem('urlRoles');
  roleList = JSON.parse(str);
} else {
  getList().then((res) => {
    roleList = res;
    localStorage.setItem('urlRoles', JSON.stringify(res));
  });
}
const routeFilter = (route: any) => {
  const { meta } = route;
  // 抽出角色
  const { auth } = meta || {};
  if (!auth) return false;
  console.log("数据查看",route)
  // 进行角色权限判断
  return roleList.some((role) => auth === role);
};
// 加入到路由集合中
Object.keys(modules).forEach((key) => {
  const mod = (modules as Recordable)[key].default || {};
  const modList = Array.isArray(mod) ? [...mod] : [mod];
  if(localStorage.getItem('urlRoles')){
    const anyRoute = filter(modList, routeFilter);
    if (anyRoute.length > 0) {
      routeModuleList.push(...anyRoute);
    }
  }
  else {
    getList().then((res) => {
      roleList = res;
      localStorage.setItem('urlRoles', JSON.stringify(res));
      window.location.reload();
    });
  }
});

export const asyncRoutes = [PAGE_NOT_FOUND_ROUTE, ...routeModuleList];

// 根路由
export const RootRoute: AppRouteRecordRaw = {
  path: '/',
  name: 'Root',
  redirect: PageEnum.BASE_HOME,
  meta: {
    title: 'Root',
  },
};

export const LoginRoute: AppRouteRecordRaw = {
  path: '/login',
  name: 'Login',
  component: () => import('@/views/sys/login/Login.vue'),
  meta: {
    title: t('routes.basic.login'),
  },
};

// Basic routing without permission
// 未经许可的基本路由
export const basicRoutes = [
  LoginRoute,
  RootRoute,
  ...mainOutRoutes,
  REDIRECT_ROUTE,
  PAGE_NOT_FOUND_ROUTE,
];
